@@ -26,14 +26,21 @@ hr_akde.track_xyt <- function(x, model = fit_ctmm(x, "iid"), keep.data = TRUE,
   suppressMessages(suppressWarnings(dat <- as_telemetry(x)))
   ud <- ctmm::akde(dat, model)
 
-  r <- 1 - ctmm::raster(ud, DF = "CDF")
-  r <- raster::projectRaster(r, to = trast)
-  r <- raster::resample(r, trast)
-  v <- raster::getValues(r)
-  v[is.na(v)] <- 0
-  r <- raster::setValues(r, v)
+  ctmm2rast <- function(x, trast) {
+    r <- ctmm::raster(x, DF = "PDF")
+    r <- raster::projectRaster(r, to = trast)
+    r <- raster::resample(r, trast)
+    v <- raster::getValues(r)
+    v[is.na(v)] <- 0
+    r <- raster::setValues(r, v)
+    r
+  }
 
-  res <- list(ud = r, model = model, levels = levels, trast = trast, estimator = "adke",
+  point.est <- ctmm2rast(ud, trast)
+
+
+  res <- list(ud = point.est, akde = ud,
+              model = model, levels = levels, trast = trast, estimator = "adke",
               crs = get_crs(x),
               data = if (keep.data) x else NULL)
   class(res) <- c("akde", "hr_prob", "hr", class(res))
